import cv2
import os

names = []


def upload_data(path):
    recogizer = cv2.face.LBPHFaceRecognizer_create()
    recogizer.read(path)
    return recogizer


def face_detect_demo(path, img):
    recogizer = upload_data(path)
    warningtime = 0
    gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
    face_detector = cv2.CascadeClassifier('haarcascade_frontalface_alt2.xml')
    face = face_detector.detectMultiScale(gray, 1.1, 5, cv2.CASCADE_SCALE_IMAGE, (100, 100), (300, 300))
    for x, y, w, h in face:
        cv2.rectangle(img, (x, y), (x + w, y + h), color=(0, 0, 255), thickness=2)
        cv2.circle(img, center=(x + w // 2, y + h // 2), radius=w // 2, color=(0, 255, 0), thickness=1)
        ids, confidence = recogizer.predict(gray[y:y + h, x:x + w])
        if confidence > 80:
            warningtime += 1
            if warningtime > 100:
                print("有坏人")
            warningtime = 0
            cv2.putText(img, 'unkonw', (x + 10, y - 10), cv2.FONT_HERSHEY_SIMPLEX, 0.75, (0, 255, 0), 1)
        else:
            cv2.putText(img, str(names[ids - 1]), (x + 10, y - 10), cv2.FONT_HERSHEY_SIMPLEX, 0.75, (0, 255, 0), 1)
    cv2.imshow('result', img)


def name(path):
    imagePaths = [os.path.join(path, f) for f in os.listdir(path)]
    for imagePath in imagePaths:
        name = str(os.path.split(imagePath)[1].split('.', 2)[1])
        names.append(name)


def recognition(path1, path2):
    cap = cv2.VideoCapture(0)
    name(path1)
    while True:
        flag, frame = cap.read()
        if not flag:
            break
        face_detect_demo(path2, frame)
        if ord(' ') == cv2.waitKey(10):
            break
    cv2.destroyAllWindows()
    cap.release()



import os
import cv2
from PIL import Image
import numpy as np


def getImageAndLabels(path, cate_path):
    facesSamples = []
    ids = []
    imagePaths = [os.path.join(path, f) for f in os.listdir(path)]
    face_detector = cv2.CascadeClassifier(cate_path)

    for imagePath in imagePaths:
        PIL_img = Image.open(imagePath).convert('L')
        img_numpy = np.array(PIL_img, 'uint8')
        faces = face_detector.detectMultiScale(img_numpy)
        id = int(os.path.split(imagePath)[1].split('.')[0])
        for x, y, w, h in faces:
            ids.append(id)
            facesSamples.append(img_numpy[y:y + h, x:x + w])

    return facesSamples, ids


def drill(path1, cate_path, path2):
    faces, ids = getImageAndLabels(path1, cate_path)
    try:
        recognizer = cv2.face.LBPHFaceRecognizer_create()
        recognizer.train(faces, np.array(ids))
        recognizer.write(path2)
    except Exception as e:
        return f'保存错误：{e}'



import cv2


def entering_face(path, name):
    cap = cv2.VideoCapture(0)
    num = 1
    while (cap.isOpened()):
        ret_flag, Vshow = cap.read()
        cv2.imshow("Capture_Test", Vshow)
        k = cv2.waitKey(1) & 0xFF
        if k == ord('s'):
            cv2.imwrite(path + str(num) + "." + name + ".jpg", Vshow)
            num += 1
        elif k == ord(' '):
            break

    cap.release()
    cv2.destroyAllWindows()



from setuptools import setup, find_packages

setup(
    name="ezfacesys",
    version="0.0.2",
    author="HeShengLi",
    author_email="2794404684@qq.com",

    description="Face entry, training and recognition library",
    # 项目主页
    url="https://gitee.com/hhslyyds/face_identification.git",
    # 你要安装的包，通过 setuptools.find_packages 找到当前目录下有哪些包
    # packages=find_packages(),
    install_requires=['certifi==2022.9.24',
                      'charset-normalizer==2.1.1',
                      'idna==3.4',
                      'numpy==1.21.6',
                      'opencv-contrib-python==4.6.0.66',
                      'opencv-python==4.6.0.66',
                      'PIL-Tools==1.1.0',
                      'Pillow==9.2.0',
                      'requests==2.28.1',
                      'urllib3==1.26.12']
)
